@@ -1,22 +1,13 @@
-/*************************************************************************
- *  Copyright (C) 2010 by Volker Lanz <vl@fidra.de>                      *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2016 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015-2015 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2015 Chris Campbell <c.j.campbell@ed.ac.uk>
 
-#if !defined(KPMCORE_PARTITIONALIGNMENT_H)
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
+#ifndef KPMCORE_PARTITIONALIGNMENT_H
 #define KPMCORE_PARTITIONALIGNMENT_H
 
 #include "QtGlobal"
