@@ -1,28 +1,17 @@
-/*************************************************************************
- *  Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                      *
- *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2014-2016 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015 Chris Campbell <c.j.campbell@ed.ac.uk>
 
-#if !defined(RESTOREOPERATION__H)
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
-#define RESTOREOPERATION__H
+#ifndef KPMCORE_RESTOREOPERATION_H
+#define KPMCORE_RESTOREOPERATION_H
 
-#include "../util/libpartitionmanagerexport.h"
+#include "util/libpartitionmanagerexport.h"
 
-#include "../ops/operation.h"
+#include "ops/operation.h"
 
 #include <QString>
 
@@ -48,7 +37,6 @@ class LIBKPMCORE_EXPORT RestoreOperation : public Operation
 {
     friend class OperationStack;
 
-    Q_OBJECT
     Q_DISABLE_COPY(RestoreOperation)
 
 public:
@@ -56,17 +44,17 @@ public:
     ~RestoreOperation();
 
 public:
-    QString iconName() const {
+    QString iconName() const override {
         return QStringLiteral("document-import");
     }
-    QString description() const;
-    bool execute(Report& parent);
-    void undo();
+    QString description() const override;
+    bool execute(Report& parent) override;
+    void undo() override;
 
-    void preview();
+    void preview() override;
 
-    virtual bool targets(const Device& d) const;
-    virtual bool targets(const Partition& p) const;
+    bool targets(const Device& d) const override;
+    bool targets(const Partition& p) const override;
 
     static bool canRestore(const Partition* p);
     static Partition* createRestorePartition(const Device& device, PartitionNode& parent, qint64 start, const QString& fileName);
